@@ -165,6 +165,41 @@ def average(event_collection, target_property, timeframe=None, timezone=None, in
                            interval=interval, filters=filters, group_by=group_by, target_property=target_property)
 
 
+def percentile(event_collection, target_property, percentile, timeframe=None, timezone=None, interval=None, filters=None,
+               group_by=None):
+    """ Performs a percentile query
+
+    Finds the percentile of a target property for events that meet the given criteria.
+
+    :param event_collection: string, the name of the collection to query
+    :param target_property: string, the name of the event property you would like use
+    :param percentile: float, the specific percentile you wish to calculate,
+    supporting 0-100 with two decimal places of precision for example, 99.99
+    :param timeframe: string or dict, the timeframe in which the events
+    happened example: "previous_7_days"
+    :param timezone: int, the timezone you'd like to use for the timeframe
+    and interval in seconds
+    :param interval: string, the time interval used for measuring data over
+    time example: "daily"
+    :param filters: array of dict, contains the filters you'd like to apply to the data
+    example: {["property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+    :param group_by: string or array of strings, the name(s) of the properties you would
+    like to group you results by.  example: "customer.id" or ["browser","operating_system"]
+
+    """
+    _initialize_client_from_environment()
+    return _client.percentile(
+        event_collection=event_collection,
+        timeframe=timeframe,
+        percentile=percentile,
+        timezone=timezone,
+        interval=interval,
+        filters=filters,
+        group_by=group_by,
+        target_property=target_property
+    )
+
+
 def count_unique(event_collection, target_property, timeframe=None, timezone=None, interval=None,
                  filters=None, group_by=None):
     """ Performs a count unique query
@@ -282,4 +317,4 @@ def multi_analysis(event_collection, analyses, timeframe=None, interval=None,
     _initialize_client_from_environment()
     return _client.multi_analysis(event_collection=event_collection, timeframe=timeframe,
                                   interval=interval, timezone=timezone, filters=filters,
-                                  group_by=group_by, analyses=analyses)
\ No newline at end of file
+                                  group_by=group_by, analyses=analyses)
