@@ -288,6 +288,40 @@ class KeenClient(object):
                                  interval=interval, filters=filters, group_by=group_by, target_property=target_property)
         return self.api.query("average", params)
 
+    def percentile(self, event_collection, target_property, percentile, timeframe=None, timezone=None, interval=None, filters=None,
+                   group_by=None):
+        """ Performs a percentile query
+
+        Finds the percentile of a target property for events that meet the given criteria.
+
+        :param event_collection: string, the name of the collection to query
+        :param target_property: string, the name of the event property you would like use
+        :param percentile: float, the specific percentile you wish to calculate,
+        supporting 0-100 with two decimal places of precision for example, 99.99
+        :param timeframe: string or dict, the timeframe in which the events
+        happened example: "previous_7_days"
+        :param timezone: int, the timezone you'd like to use for the timeframe
+        and interval in seconds
+        :param interval: string, the time interval used for measuring data over
+        time example: "daily"
+        :param filters: array of dict, contains the filters you'd like to apply to the data
+        example: [{"property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+        :param group_by: string or array of strings, the name(s) of the properties you would
+        like to group you results by.  example: "customer.id" or ["browser","operating_system"]
+
+        """
+        params = self.get_params(
+            event_collection=event_collection,
+            timeframe=timeframe,
+            percentile=percentile,
+            timezone=timezone,
+            interval=interval,
+            filters=filters,
+            group_by=group_by,
+            target_property=target_property
+        )
+        return self.api.query("percentile", params)
+
     def count_unique(self, event_collection, target_property, timeframe=None, timezone=None, interval=None,
                      filters=None, group_by=None):
         """ Performs a count unique query
@@ -410,7 +444,7 @@ class KeenClient(object):
 
     def get_params(self, event_collection=None, timeframe=None, timezone=None, interval=None, filters=None,
                    group_by=None, target_property=None, latest=None, email=None, analyses=None, steps=None,
-                   property_names=None):
+                   property_names=None, percentile=None):
         params = {}
         if event_collection:
             params["event_collection"] = event_collection
@@ -442,5 +476,7 @@ class KeenClient(object):
             params["steps"] = json.dumps(steps)
         if property_names:
             params["property_names"] = json.dumps(property_names)
+        if percentile:
+            params["percentile"] = percentile
 
         return params
